[OE-core] [PATCH 1/1] replace portmap with rpcbind.

rongqing.li at windriver.com rongqing.li at windriver.com
Mon Dec 24 01:02:04 UTC 2012


From: "Roy.Li" <rongqing.li at windriver.com>

Rpcbind has more features, like ipv6 support and nfs4 support;
Redhat, Fedora, debian, Ubuntu are using rpcbind by default.

Signed-off-by: Roy.Li <rongqing.li at windriver.com>
---
 meta/recipes-connectivity/nfs-utils/nfs-utils_1.2.3.bb |    2 +-
 .../initscripts/initscripts-1.0/mountnfs.sh            |   16 ++++++++--------
 meta/recipes-core/packagegroups/packagegroup-base.bb   |    2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/meta/recipes-connectivity/nfs-utils/nfs-utils_1.2.3.bb b/meta/recipes-connectivity/nfs-utils/nfs-utils_1.2.3.bb
index 5a4a7e7..84b8e76 100644
--- a/meta/recipes-connectivity/nfs-utils/nfs-utils_1.2.3.bb
+++ b/meta/recipes-connectivity/nfs-utils/nfs-utils_1.2.3.bb
@@ -9,7 +9,7 @@ LIC_FILES_CHKSUM = "file://COPYING;md5=0636e73ff0215e8d672dc4c32c317bb3"
 
 # util-linux for libblkid
 DEPENDS = "libcap libnfsidmap libevent util-linux tcp-wrappers"
-RDEPENDS_${PN} = "portmap"
+RDEPENDS_${PN} = "rpcbind"
 RRECOMMENDS_${PN} = "kernel-module-nfsd"
 
 PR = "r5"
diff --git a/meta/recipes-core/packagegroups/packagegroup-base.bb b/meta/recipes-core/packagegroups/packagegroup-base.bb
index 347a7e1..b3cdbad 100644
--- a/meta/recipes-core/packagegroups/packagegroup-base.bb
+++ b/meta/recipes-core/packagegroups/packagegroup-base.bb
@@ -328,7 +328,7 @@ RRECOMMENDS_packagegroup-base-cramfs = "\
 #
 SUMMARY_packagegroup-base-nfs = "NFS network filesystem support"
 RDEPENDS_packagegroup-base-nfs = "\
-    portmap"
+    rpcbind"
 
 RRECOMMENDS_packagegroup-base-nfs = "\
     kernel-module-nfs "
diff --git a/meta/recipes-core/initscripts/initscripts-1.0/mountnfs.sh b/meta/recipes-core/initscripts/initscripts-1.0/mountnfs.sh
index 82ec7f6..4fffe4e 100755
--- a/meta/recipes-core/initscripts/initscripts-1.0/mountnfs.sh
+++ b/meta/recipes-core/initscripts/initscripts-1.0/mountnfs.sh
@@ -1,7 +1,7 @@
 #!/bin/sh
 ### BEGIN INIT INFO
 # Provides:          mountnfs
-# Required-Start:    $local_fs $network $portmap
+# Required-Start:    $local_fs $network $rpcbind
 # Required-Stop:
 # Default-Start:     S
 # Default-Stop:
@@ -17,9 +17,9 @@ test -f /etc/fstab && (
 #
 #	Read through fstab line by line. If it is NFS, set the flag
 #	for mounting NFS filesystems. If any NFS partition is found and it
 #	not mounted with the nolock option, we start the portmapper.
 #
-portmap=no
+rpcbind=no
 mount_nfs=no
 mount_smb=no
 mount_ncp=no
@@ -45,7 +45,7 @@ do
 			*nolock*)
 				;;
 			*)
-				portmap=yes
+				rpcbind=yes
 				;;
 		esac
 	fi
@@ -65,12 +65,12 @@ done
 
 exec 0>&1
 
-if test "$portmap" = yes
+if test "$rpcbind" = yes
 then
-	if test -x /sbin/portmap
+	if test -x /usr/sbin/rpcbind
 	then
-		echo -n "Starting portmapper... "
-		start-stop-daemon --start --quiet --exec /sbin/portmap
+		echo -n "Starting rpcbind... "
+		start-stop-daemon --start --quiet --exec /usr/sbin/rpcbind
 		sleep 2
 	fi
 fi
@@ -17,9 +17,9 @@ test -f /etc/fstab && (
 #	Read through fstab line by line. If it is NFS, set the flag
 #	for mounting NFS filesystems. If any NFS partition is found and it
-#	not mounted with the nolock option, we start the portmapper.
+#	not mounted with the nolock option, we start the rpcbind.
 #
-- 
1.7.10.4





More information about the Openembedded-core mailing list